import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';
import 'package:hx_components_flutter/src/shared/styles.dart';

// ignore: must_be_immutable
class HxButton extends StatefulWidget {
  final String? title;
  bool disabled;
  final bool isLoading;
  final void Function()? onTap;
  final IconData? prefixIcon;
  final double? fontSize;
  final double? iconSize;
  final bool isSmallButton;
  final double isLoadingHorizontalPadding;
  final double isLoadingVerticalPadding;
  final bool wrapAroundContent;

  Color hoverColor = kcSecondaryColor;
  Color? backgroundColor;
  Color? fillColor;

  HxButton({
    super.key,
    this.title,
    this.disabled = false,
    this.isLoading = false,
    this.onTap,
    this.prefixIcon,
    this.fontSize = 16,
    this.iconSize = 18,
    this.isSmallButton = false,
    this.isLoadingVerticalPadding = 8,
    this.isLoadingHorizontalPadding = 20,
    this.wrapAroundContent = true,
  })  : backgroundColor = kcPrimaryColor,
        fillColor = kcBackgroundColor;

  HxButton.secondary({
    super.key,
    this.title,
    this.disabled = false,
    this.isLoading = false,
    this.onTap,
    this.prefixIcon,
    this.fontSize = 16,
    this.iconSize = 18,
    this.isSmallButton = false,
    this.isLoadingVerticalPadding = 8,
    this.isLoadingHorizontalPadding = 20,
    this.wrapAroundContent = true,
  })  : backgroundColor = kcTertiaryColor,
        fillColor = kcPrimaryColor;

  @override
  State<HxButton> createState() => _HxButtonState();
}

class _HxButtonState extends State<HxButton> {
  Color hoverColor = kcSecondaryColor;
  bool isOnHover = false;

  @override
  Widget build(BuildContext context) {
    final bool isIconButton = widget.prefixIcon != null && widget.title == null;

    if (widget.onTap == null) {
      widget.disabled = true;
    }

    void _triggerHoverEvent(PointerEvent details) {
      setState(() {
        isOnHover = true;
      });
    }

    void _triggerExitEvent(PointerEvent details) {
      setState(() {
        isOnHover = false;
      });
    }

    return Center(
      child: MouseRegion(
        onHover: _triggerHoverEvent,
        onExit: _triggerExitEvent,
        child: InkWell(
          hoverColor: widget.hoverColor,
          splashFactory: InkRipple.splashFactory,
          onTap: widget.isLoading || widget.disabled ? null : widget.onTap,
          borderRadius: BorderRadius.circular(12),
          child: Ink(
            height: widget.isSmallButton ? 45 : 65,
            decoration: BoxDecoration(
              color: widget.disabled
                  ? kcDisabled
                  : isOnHover
                      ? hoverColor
                      : widget.backgroundColor,
              borderRadius: BorderRadius.circular(12),
            ),
            child: Padding(
              padding: EdgeInsets.symmetric(
                vertical: 6,
                horizontal: widget.prefixIcon != null ? 12 : 26,
              ),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.center,
                mainAxisSize: widget.wrapAroundContent ? MainAxisSize.min : MainAxisSize.max,
                children: widget.isLoading
                    ? [
                        Padding(
                          padding: EdgeInsets.symmetric(
                            vertical: widget.isLoadingVerticalPadding == 8 && widget.isSmallButton ? 0 : widget.isLoadingVerticalPadding,
                            horizontal: widget.isLoadingHorizontalPadding,
                          ),
                          child: CircularProgressIndicator(
                            strokeWidth: 5,
                            valueColor: AlwaysStoppedAnimation(
                              widget.disabled
                                  ? kcBackgroundColor
                                  : isOnHover
                                      ? kcBackgroundColor
                                      : widget.fillColor,
                            ),
                          ),
                        ),
                      ]
                    : [
                        if (widget.prefixIcon != null)
                          Icon(
                            widget.prefixIcon,
                            color: widget.disabled || isOnHover ? kcBackgroundColor : widget.fillColor,
                            size: isIconButton && widget.iconSize == 18 ? 25 : widget.iconSize,
                          ),
                        if (!isIconButton) const SizedBox(width: 2),
                        if (widget.title != null)
                          Text(
                            widget.title!,
                            style: bodyStyle.copyWith(
                              fontWeight: FontWeight.w400,
                              color: widget.disabled || isOnHover ? kcBackgroundColor : widget.fillColor,
                              fontSize: widget.fontSize,
                            ),
                          ),
                      ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
