import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';
import 'package:hx_components_flutter/src/shared/styles.dart';

class HxOutlineButton extends StatefulWidget {
  final String? title;
  final bool isLoading;
  final void Function()? onTap;
  final IconData? prefixIcon;
  final double? fontSize;
  final double? iconSize;
  final bool isSmallButton;
  final double isLoadingHorizontalPadding;
  final double isLoadingVerticalPadding;
  final bool wrapAroundContent;

  const HxOutlineButton({
    super.key,
    this.title,
    this.isLoading = false,
    this.onTap,
    this.prefixIcon,
    this.fontSize = 16,
    this.iconSize = 18,
    this.isSmallButton = false,
    this.isLoadingVerticalPadding = 8,
    this.isLoadingHorizontalPadding = 20,
    this.wrapAroundContent = true,
  });

  @override
  State<HxOutlineButton> createState() => _HxButtonState();
}

class _HxButtonState extends State<HxOutlineButton> {
  Color hoverColor = kcSecondaryColor;

  @override
  Widget build(BuildContext context) {
    final bool isIconButton = widget.prefixIcon != null && widget.title == null;

    return Center(
      child: InkWell(
        mouseCursor: widget.onTap != null ? SystemMouseCursors.click : null,
        onTap: widget.isLoading ? null : widget.onTap,
        borderRadius: BorderRadius.circular(12),
        child: Ink(
          height: widget.isSmallButton ? 45 : 65,
          decoration: BoxDecoration(
            color: Colors.transparent,
            borderRadius: BorderRadius.circular(12),
            border: Border.all(
              color: kcPrimaryColor,
            ),
          ),
          child: Padding(
            padding: EdgeInsets.symmetric(
              vertical: 6,
              horizontal: widget.prefixIcon != null ? 12 : 26,
            ),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              mainAxisSize: widget.wrapAroundContent ? MainAxisSize.min : MainAxisSize.max,
              children: widget.isLoading
                  ? [
                      Padding(
                        padding: EdgeInsets.symmetric(
                          vertical: widget.isLoadingVerticalPadding == 8 && widget.isSmallButton ? 0 : widget.isLoadingVerticalPadding,
                          horizontal: widget.isLoadingHorizontalPadding,
                        ),
                        child: const CircularProgressIndicator(
                          strokeWidth: 5,
                          valueColor: AlwaysStoppedAnimation(kcPrimaryColor),
                        ),
                      ),
                    ]
                  : [
                      if (widget.prefixIcon != null)
                        Icon(
                          widget.prefixIcon,
                          color: kcPrimaryColor,
                          size: isIconButton && widget.iconSize == 18 ? 25 : widget.iconSize,
                        ),
                      if (!isIconButton) const SizedBox(width: 2),
                      if (widget.title != null)
                        Text(
                          widget.title!,
                          style: bodyStyle.copyWith(
                            fontWeight: FontWeight.w400,
                            color: kcPrimaryColor,
                            fontSize: widget.fontSize,
                          ),
                        ),
                    ],
            ),
          ),
        ),
      ),
    );
  }
}
